@@ -6,7 +6,7 @@ import pkg_resources
 from fabric.api import env
 from fabric.api import local
 from fabric.api import puts
-from fabric.api import task
+from farmboy.fabric_ import task
 
 
 def _makedir(p):
@@ -18,7 +18,6 @@ def _makedir(p):
           pass
 
 
-
 @task
 def init(force=False):
   """Copy the template files to the local directory for easy modification."""
